@@ -760,7 +760,8 @@ add_account (GoaProvider    *provider,
 
   g_free (data.access_token);
   g_free (data.account_object_path);
-  g_clear_pointer (&data.loop, (GDestroyNotify) g_main_loop_unref);
+  if (data.loop != NULL)
+    g_main_loop_unref (data.loop);
   g_clear_object (&data.cancellable);
   return ret;
 }
@@ -890,7 +891,8 @@ refresh_account (GoaProvider    *provider,
     g_propagate_error (error, data.error);
 
   gtk_widget_destroy (dialog);
-  g_clear_pointer (&data.loop, (GDestroyNotify) g_main_loop_unref);
+  if (data.loop != NULL)
+    g_main_loop_unref (data.loop);
   g_free (data.access_token);
   g_clear_object (&data.cancellable);
   return ret;
